@@ -1,4 +1,4 @@
-/* $Id: slave.c,v 1.14 1999/02/23 11:43:45 martin Exp $ */
+/* $Id: slave.c,v 1.14.2.1 1999/05/27 23:30:11 martin Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -128,7 +128,7 @@ handle_slave_command (glibtop_command *cmnd, glibtop_response *resp,
 			sizeof (glibtop_sysdeps));
 		resp->u.sysdeps.features = glibtop_server_features;
 		resp->u.sysdeps.flags = glibtop_server_features |
-		  (1 << GLIBTOP_SYSDEPS_FEATURES);
+		  (1L << GLIBTOP_SYSDEPS_FEATURES);
 		resp->offset = _offset_union (sysdeps);
 		break;
 #if GLIBTOP_SUID_CPU
