@@ -1,4 +1,4 @@
-/* $Id: prockernel.c,v 1.19 1999/02/25 20:44:30 martin Exp $ */
+/* $Id: prockernel.c,v 1.19.4.2 1999/05/27 14:04:03 martin Exp $ */
 
 /* Copyright (C) 1998 Joshua Sled
    This file is part of LibGTop 1.0.
@@ -31,10 +31,12 @@
 #include <sys/param.h>
 #include <sys/sysctl.h>
 #include <sys/proc.h>
-#ifndef __OpenBSD__
+#if (!defined __OpenBSD__) && (!defined __bsdi__)
 #include <sys/user.h>
 #endif
+#ifndef __bsdi__
 #include <machine/pcb.h>
+#endif
 #ifdef __FreeBSD__
 #include <machine/tss.h>
 #endif
@@ -47,18 +49,18 @@
 #endif
 
 static const unsigned long _glibtop_sysdeps_proc_kernel_pstats =
-(1 << GLIBTOP_PROC_KERNEL_MIN_FLT) +
-(1 << GLIBTOP_PROC_KERNEL_MAJ_FLT) +
-(1 << GLIBTOP_PROC_KERNEL_CMIN_FLT) +
-(1 << GLIBTOP_PROC_KERNEL_CMAJ_FLT);
+(1L << GLIBTOP_PROC_KERNEL_MIN_FLT) +
+(1L << GLIBTOP_PROC_KERNEL_MAJ_FLT) +
+(1L << GLIBTOP_PROC_KERNEL_CMIN_FLT) +
+(1L << GLIBTOP_PROC_KERNEL_CMAJ_FLT);
 
 static const unsigned long _glibtop_sysdeps_proc_kernel_pcb =
-(1 << GLIBTOP_PROC_KERNEL_KSTK_EIP) +
-(1 << GLIBTOP_PROC_KERNEL_KSTK_ESP);
+(1L << GLIBTOP_PROC_KERNEL_KSTK_EIP) +
+(1L << GLIBTOP_PROC_KERNEL_KSTK_ESP);
 
 static const unsigned long _glibtop_sysdeps_proc_kernel_wchan =
-(1 << GLIBTOP_PROC_KERNEL_NWCHAN) +
-(1 << GLIBTOP_PROC_KERNEL_WCHAN);
+(1L << GLIBTOP_PROC_KERNEL_NWCHAN) +
+(1L << GLIBTOP_PROC_KERNEL_WCHAN);
 
 /* Init function. */
 
@@ -84,7 +86,7 @@ glibtop_get_proc_kernel_p (glibtop *server,
 	char filename [BUFSIZ];
 	struct stat statb;
 
-	glibtop_init_p (server, (1 << GLIBTOP_SYSDEPS_PROC_KERNEL), 0);
+	glibtop_init_p (server, (1L << GLIBTOP_SYSDEPS_PROC_KERNEL), 0);
 	
 	memset (buf, 0, sizeof (glibtop_proc_kernel));
 
@@ -100,13 +102,13 @@ glibtop_get_proc_kernel_p (glibtop *server,
 		glibtop_error_io_r (server, "kvm_getprocs (%d)", pid);
 
 	buf->nwchan = (unsigned long) pinfo [0].kp_proc.p_wchan &~ KERNBASE;
-	buf->flags |= (1 << GLIBTOP_PROC_KERNEL_NWCHAN);
+	buf->flags |= (1L << GLIBTOP_PROC_KERNEL_NWCHAN);
 
 	if (pinfo [0].kp_proc.p_wchan && pinfo [0].kp_proc.p_wmesg) {
 		strncpy (buf->wchan, pinfo [0].kp_eproc.e_wmesg,
 			 sizeof (buf->wchan) - 1);
 		buf->wchan [sizeof (buf->wchan) - 1] = 0;
-		buf->flags |= (1 << GLIBTOP_PROC_KERNEL_WCHAN);
+		buf->flags |= (1L << GLIBTOP_PROC_KERNEL_WCHAN);
 	} else {
 		buf->wchan [0] = 0;
 	}
@@ -122,7 +124,7 @@ glibtop_get_proc_kernel_p (glibtop *server,
 	/* NOTE: You need to mount the /proc filesystem to make
 	 *       `kvm_uread' work. */
 
-	sprintf (filename, "/proc/%d/mem", pid);
+	sprintf (filename, "/proc/%d/mem", (int) pid);
 	if (stat (filename, &statb)) return;
 
 	glibtop_suid_enter (server);
@@ -162,7 +164,11 @@ glibtop_get_proc_kernel_p (glibtop *server,
 #endif
 #else
 			buf->kstk_esp = (u_int64_t) pcb.pcb_tss.tss_esp0;
+#ifdef __bsdi__
+			buf->kstk_eip = (u_int64_t) pcb.pcb_tss.tss_eip;
+#else
 			buf->kstk_eip = (u_int64_t) pcb.pcb_tss.__tss_eip;
+#endif
 
 			buf->flags |= _glibtop_sysdeps_proc_kernel_pcb;
 #endif
