@@ -1,4 +1,4 @@
-/* $Id: procsignal.c,v 1.12 1999/02/23 11:44:15 martin Exp $ */
+/* $Id: procsignal.c,v 1.12.2.1 1999/05/27 14:04:09 martin Exp $ */
 
 /* Copyright (C) 1998 Joshua Sled
    This file is part of LibGTop 1.0.
@@ -28,10 +28,10 @@
 #include <glibtop_suid.h>
 
 static const unsigned long _glibtop_sysdeps_proc_signal =
-(1 << GLIBTOP_PROC_SIGNAL_SIGNAL) +
-(1 << GLIBTOP_PROC_SIGNAL_BLOCKED) +
-(1 << GLIBTOP_PROC_SIGNAL_SIGIGNORE) +
-(1 << GLIBTOP_PROC_SIGNAL_SIGCATCH);
+(1L << GLIBTOP_PROC_SIGNAL_SIGNAL) +
+(1L << GLIBTOP_PROC_SIGNAL_BLOCKED) +
+(1L << GLIBTOP_PROC_SIGNAL_SIGIGNORE) +
+(1L << GLIBTOP_PROC_SIGNAL_SIGCATCH);
 
 /* Init function. */
 
@@ -49,7 +49,7 @@ glibtop_get_proc_signal_p (glibtop *server,
 	struct kinfo_proc *pinfo;
 	int count = 0;
 
-	glibtop_init_p (server, (1 << GLIBTOP_SYSDEPS_PROC_SIGNAL), 0);
+	glibtop_init_p (server, (1L << GLIBTOP_SYSDEPS_PROC_SIGNAL), 0);
 	
 	memset (buf, 0, sizeof (glibtop_proc_signal));
 
