@@ -1,4 +1,4 @@
-/* $Id: procstate.c,v 1.12 1999/02/23 11:44:16 martin Exp $ */
+/* $Id: procstate.c,v 1.12.4.3 1999/05/27 18:56:50 martin Exp $ */
 
 /* Copyright (C) 1998 Joshua Sled
    This file is part of LibGTop 1.0.
@@ -27,20 +27,29 @@
 
 #include <glibtop_suid.h>
 
-#ifndef __OpenBSD__
+#if !defined(__OpenBSD__) 
+//&& (!defined __bsdi__)
 #include <sys/user.h>
 #endif
 
 static const unsigned long _glibtop_sysdeps_proc_state =
-(1 << GLIBTOP_PROC_STATE_CMD) + (1 << GLIBTOP_PROC_STATE_STATE) +
-(1 << GLIBTOP_PROC_STATE_UID) + (1 << GLIBTOP_PROC_STATE_GID);
+(1L << GLIBTOP_PROC_STATE_CMD) + (1L << GLIBTOP_PROC_STATE_UID) +
+(1L << GLIBTOP_PROC_STATE_GID);
+
+static const unsigned long _glibtop_sysdeps_proc_state_new =
+#if LIBGTOP_VERSION_CODE >= 1001000
+(1L << GLIBTOP_PROC_STATE_RUID) + (1L << GLIBTOP_PROC_STATE_RGID);
+#else
+0;
+#endif
 
 /* Init function. */
 
 void
 glibtop_init_proc_state_p (glibtop *server)
 {
-	server->sysdeps.proc_state = _glibtop_sysdeps_proc_state;
+	server->sysdeps.proc_state = _glibtop_sysdeps_proc_state |
+		_glibtop_sysdeps_proc_state_new;
 }
 
 /* Provides detailed information about a process. */
@@ -53,7 +62,7 @@ glibtop_get_proc_state_p (glibtop *server,
 	struct kinfo_proc *pinfo;
 	int count = 0;
 
-	glibtop_init_p (server, (1 << GLIBTOP_SYSDEPS_PROC_STATE), 0);
+	glibtop_init_p (server, (1L << GLIBTOP_SYSDEPS_PROC_STATE), 0);
 	
 	memset (buf, 0, sizeof (glibtop_proc_state));
 
@@ -73,27 +82,34 @@ glibtop_get_proc_state_p (glibtop *server,
 	buf->uid = pinfo [0].kp_eproc.e_pcred.p_svuid;
 	buf->gid = pinfo [0].kp_eproc.e_pcred.p_svgid;
 
-	switch (pinfo [0].kp_proc.p_stat) {
-	case SIDL:
-		buf->state = 'I';
-		break;
-	case SRUN:
-		buf->state = 'R';
-		break;
-	case SSLEEP:
-		buf->state = 'S';
-		break;
-	case SSTOP:
-		buf->state = 'T';
-		break;
-	case SZOMB:
-		buf->state = 'Z';
-		break;
-	default:
-		buf->state = '?';
-		break;
-	}
+#if LIBGTOP_VERSION_CODE >= 1001000
+	buf->ruid = pinfo [0].kp_eproc.e_pcred.p_ruid;
+	buf->rgid = pinfo [0].kp_eproc.e_pcred.p_rgid;
+#endif
 
 	/* Set the flags for the data we're about to return*/
-	buf->flags = _glibtop_sysdeps_proc_state;
+	buf->flags = _glibtop_sysdeps_proc_state |
+		_glibtop_sysdeps_proc_state_new;
+
+	switch (pinfo [0].kp_proc.p_stat) {
+	case SIDL:
+		buf->state = 0;
+		break;
+	case SRUN:
+		buf->state = GLIBTOP_PROCESS_RUNNING;
+		break;
+	case SSLEEP:
+		buf->state = GLIBTOP_PROCESS_INTERRUPTIBLE;
+		break;
+	case SSTOP:
+		buf->state = GLIBTOP_PROCESS_STOPPED;
+		break;
+	case SZOMB:
+		buf->state = GLIBTOP_PROCESS_ZOMBIE;
+		break;
+	default:
+		return;
+	}
+
+	buf->flags |= (1L << GLIBTOP_PROC_STATE_STATE);
 }
