@@ -1,4 +1,4 @@
-/* $Id: procuid.c,v 1.9 1999/02/23 11:44:18 martin Exp $ */
+/* $Id: procuid.c,v 1.9.2.2 1999/05/27 18:56:52 martin Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -28,18 +28,28 @@
 #include <glibtop_suid.h>
 
 static const unsigned long _glibtop_sysdeps_proc_uid =
-(1 << GLIBTOP_PROC_UID_UID) + (1 << GLIBTOP_PROC_UID_EUID) +
-(1 << GLIBTOP_PROC_UID_EGID) + (1 << GLIBTOP_PROC_UID_PID) +
-(1 << GLIBTOP_PROC_UID_PPID) + (1 << GLIBTOP_PROC_UID_PGRP) +
-(1 << GLIBTOP_PROC_UID_TPGID) + (1 << GLIBTOP_PROC_UID_PRIORITY) +
-(1 << GLIBTOP_PROC_UID_NICE);
+(1L << GLIBTOP_PROC_UID_UID) + (1L << GLIBTOP_PROC_UID_EUID) +
+(1L << GLIBTOP_PROC_UID_EGID) + (1L << GLIBTOP_PROC_UID_PID) +
+(1L << GLIBTOP_PROC_UID_PPID) + (1L << GLIBTOP_PROC_UID_PGRP) +
+(1L << GLIBTOP_PROC_UID_TPGID) + (1L << GLIBTOP_PROC_UID_PRIORITY) +
+(1L << GLIBTOP_PROC_UID_NICE);
+
+static const unsigned long _glibtop_sysdeps_proc_uid_groups =
+#if LIBGTOP_VERSION_CODE >= 1001000
+#if defined(__NetBSD__) && (__NetBSD_Version__ >= 104000000)
+(1L << GLIBTOP_PROC_UID_NGROUPS) + (1L << GLIBTOP_PROC_UID_GROUPS);
+#endif
+#else
+0;
+#endif
 
 /* Init function. */
 
 void
 glibtop_init_proc_uid_p (glibtop *server)
 {
-	server->sysdeps.proc_uid = _glibtop_sysdeps_proc_uid;
+	server->sysdeps.proc_uid = _glibtop_sysdeps_proc_uid |
+		_glibtop_sysdeps_proc_uid_groups;
 }
 
 /* Provides detailed information about a process. */
@@ -51,7 +61,14 @@ glibtop_get_proc_uid_p (glibtop *server, glibtop_proc_uid *buf,
 	struct kinfo_proc *pinfo;
 	int count = 0;
 
-	glibtop_init_p (server, (1 << GLIBTOP_SYSDEPS_PROC_UID), 0);
+#if LIBGTOP_VERSION_CODE >= 1001000
+#if defined(__NetBSD__) && (__NetBSD_Version__ >= 104000000)
+	struct ucred ucred;
+	void *ucred_ptr;
+#endif
+#endif
+
+	glibtop_init_p (server, (1L << GLIBTOP_SYSDEPS_PROC_UID), 0);
 	
 	memset (buf, 0, sizeof (glibtop_proc_uid));
 
@@ -80,4 +97,30 @@ glibtop_get_proc_uid_p (glibtop *server, glibtop_proc_uid *buf,
 	/* Set the flags for the data we're about to return*/
 	buf->flags = _glibtop_sysdeps_proc_uid;
 
+	/* Use LibGTop conditionals here so we can more easily merge this
+	 * code into the LIBGTOP_STABLE_1_0 branch. */
+#if LIBGTOP_VERSION_CODE >= 1001000
+	/* This probably also works with other versions, but not yet
+	 * tested. Please remove the conditional if this is true. */
+#if defined(__NetBSD__) && (__NetBSD_Version__ >= 104000000)
+	ucred_ptr = (void *) pinfo [0].kp_eproc.e_pcred.pc_ucred;
+
+	if (ucred_ptr) {
+		if (kvm_read (server->machine.kd, (unsigned long) ucred_ptr,
+			      &ucred, sizeof (ucred)) != sizeof (ucred)) {
+			glibtop_warn_io_r (server, "kvm_read (ucred)");
+		} else {
+			int count = (ucred.cr_ngroups < GLIBTOP_MAX_GROUPS) ?
+				ucred.cr_ngroups : GLIBTOP_MAX_GROUPS;
+			int i;
+
+			for (i = 0; i < count; i++)
+				buf->groups [i] = ucred.cr_groups [i];
+			buf->ngroups = count;
+
+			buf->flags |= _glibtop_sysdeps_proc_uid_groups;
+		}
+	}
+#endif
+#endif
 }
