@@ -1,4 +1,4 @@
-/* $Id: ppp.c,v 1.4 1999/02/23 11:45:02 martin Exp $ */
+/* $Id: ppp.c,v 1.4.2.1 1999/05/27 19:24:17 martin Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -34,8 +34,8 @@
 #include <glib.h>
 
 static const unsigned long _glibtop_sysdeps_ppp =
-(1 << GLIBTOP_PPP_STATE) + (1 << GLIBTOP_PPP_BYTES_IN) +
-(1 << GLIBTOP_PPP_BYTES_OUT);
+(1L << GLIBTOP_PPP_STATE) + (1L << GLIBTOP_PPP_BYTES_IN) +
+(1L << GLIBTOP_PPP_BYTES_OUT);
 
 /* Init function. */
 
@@ -187,13 +187,13 @@ glibtop_get_ppp_s (glibtop *server, glibtop_ppp *buf, unsigned short device)
 	if (is_ISDN_on (server, &online)) {
 		buf->state = online ? GLIBTOP_PPP_STATE_ONLINE :
 			GLIBTOP_PPP_STATE_HANGUP;
-		buf->flags |= (1 << GLIBTOP_PPP_STATE);
+		buf->flags |= (1L << GLIBTOP_PPP_STATE);
 	}
 
 	if (get_ISDN_stats (server, &in, &out)) {
 		buf->bytes_in = in;
 		buf->bytes_out = out;
-		buf->flags |= (1 << GLIBTOP_PPP_BYTES_IN) |
-			(1 << GLIBTOP_PPP_BYTES_OUT);
+		buf->flags |= (1L << GLIBTOP_PPP_BYTES_IN) |
+			(1L << GLIBTOP_PPP_BYTES_OUT);
 	}
 }
